@@ -12,7 +12,7 @@ Usage::
     session_client: WorkMailMessageFlowClient = session.client("workmailmessageflow")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, TYPE_CHECKING
+from typing import Any, Dict, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_workmailmessageflow.type_defs import GetRawMessageContentResponseTypeDef
 
@@ -21,20 +21,20 @@ __all__ = ("WorkMailMessageFlowClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
 
 
 class WorkMailMessageFlowClient:
     """
-    [WorkMailMessageFlow.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client)
+    [WorkMailMessageFlow.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -45,10 +45,10 @@ class WorkMailMessageFlowClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.generate_presigned_url)
         """
 
     def get_raw_message_content(self, messageId: str) -> GetRawMessageContentResponseTypeDef:
         """
-        [Client.get_raw_message_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.get_raw_message_content)
+        [Client.get_raw_message_content documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.get_raw_message_content)
         """
